@@ -253,6 +253,9 @@ defaults_analyze = matrix(c(
   'specBrightness', 0, -1, 1, .05,
   'blur_freq', 0, -1000, 1000, 10,
   'blur_time', 0, -100, 100, 1,
+  'reass_cex', .5, .05, 2, .05,
+  'reass_windowLength', 15, 1, 200, 1,
+  'reass_step', 5, 1, 100, 1,
   'spec_ylim', 5, 0, 22, 0.1,
   'spec_maxPoints', 5.5, 3, 7, .25,
   'spec_cex', 1, .1, 10, .1,
@@ -331,10 +334,11 @@ def_form = matrix(c(
   'spec_ylim', 5, 0, 96, 0.1,
   'specContrast', .2, -1, 1, .05,
   'specBrightness', -.2, -1, 1, .05,
-  'blur_freq', -100, -1000, 1000, 10,
-  'blur_time', 5, -100, 100, 1,
-  'windowLength', 50, 1, 500, 1,
-  'step', 25, 1, 100, 1,
+  'blur_freq', 0, -1000, 1000, 10,
+  'blur_time', 0, -100, 100, 1,
+  'reass_cex', .25, .05, 2, .05,
+  'windowLength', 8, 1, 500, 1,
+  'step', 2, 1, 100, 1,
   'overlap', 50, 0, 99, 1,
   'dynamicRange', 80, 10, 200, 10,
   'zp', 0, 0, 13, 1,
