@@ -227,6 +227,12 @@ ui = fluidPage(
                 #   min = def_form['overlap', 'low'],
                 #   max = def_form['overlap', 'high'],
                 #   step = def_form['overlap', 'step']),
+                radioButtons(
+                  inputId = 'specType',
+                  label = 'Spectrogram method',
+                  choices = c("Ordinary FFT" = "spectrum",
+                              "Reassigned" = "reassigned"),
+                  selected = 'spectrum', inline = TRUE, width = NULL),
                 sliderInput(
                   'dynamicRange',
                   'Dynamic range, dB',
@@ -270,6 +276,27 @@ ui = fluidPage(
                     value = '#FF0000FF', # red
                     placeholder = '#FF0000FF'
                   ),
+                  sliderInput(
+                    'blur_freq',
+                    'Blur: frequency (Hz)',
+                    value = def_form['blur_freq', 'default'],
+                    min = def_form['blur_freq', 'low'],
+                    max = def_form['blur_freq', 'high'],
+                    step = def_form['blur_freq', 'step']),
+                  sliderInput(
+                    'blur_time',
+                    'Blur: time (ms)',
+                    value = def_form['blur_time', 'default'],
+                    min = def_form['blur_time', 'low'],
+                    max = def_form['blur_time', 'high'],
+                    step = def_form['blur_time', 'step']),
+                  sliderInput(
+                    'reass_cex',
+                    'Point size (reassigned spectrogram only)',
+                    value = def_form['reass_cex', 'default'],
+                    min = def_form['reass_cex', 'low'],
+                    max = def_form['reass_cex', 'high'],
+                    step = def_form['reass_cex', 'step']),
                   sliderInput(
                     'zp',
                     'Zero padding, points 2 ^ n',
